@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2014 IBM Corporation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,6 +13,6 @@
 # limitations under the License.
 
 
-class Health:
+class Health(object):
     Ok = 0
     Warning, Critical, Failed = [2**x for x in range(0, 3)]
