@@ -211,11 +211,25 @@ class OEMHandler(generic.OEMHandler):
             self._mrethidx = rsp['data'][0]
         return self._mrethidx
 
+    def get_screenshot(self, outfile):
+        if self.has_xcc:
+            return self.immhandler.get_screenshot(outfile)
+        return {}
+
     def remove_storage_configuration(self, cfgspec):
         if self.has_xcc:
             return self.immhandler.remove_storage_configuration(cfgspec)
         return super(OEMHandler, self).remove_storage_configuration()
 
+    def get_ikvm_methods(self):
+        if self.has_xcc:
+            return ['url']
+
+    def get_ikvm_launchdata(self):
+        if self.has_xcc:
+            return self.immhandler.get_ikvm_launchdata()
+        return {}
+
     def clear_storage_arrays(self):
         if self.has_xcc:
             return self.immhandler.clear_storage_arrays()
@@ -671,9 +685,11 @@ class OEMHandler(generic.OEMHandler):
                                         led_status_default)
             yield (name, {'status': status})
 
-    def set_identify(self, on, duration):
+    def set_identify(self, on, duration, blink):
         if on and not duration and self.is_sd350:
             self.ipmicmd.xraw_command(netfn=0x3a, command=6, data=(1, 1))
+        elif self.has_xcc:
+            self.immhandler.set_identify(on, duration, blink)
         else:
             raise pygexc.UnsupportedFunctionality()
 
@@ -1173,6 +1189,13 @@ class OEMHandler(generic.OEMHandler):
                 else:
                     raise
 
+    def get_update_status(self):
+        if self.is_fpc or self.has_tsma:
+            return "ready"
+        if self.has_xcc:
+            return self.immhandler.get_update_status()
+        return super(OEMHandler, self).get_update_status()
+
     def update_firmware(self, filename, data=None, progress=None, bank=None):
         if self.has_xcc:
             return self.immhandler.update_firmware(
@@ -1194,9 +1217,9 @@ class OEMHandler(generic.OEMHandler):
             return {'height': self._fpc_variant & 0xf, 'slot': 0}
         return super(OEMHandler, self).get_description()
 
-    def get_extended_bmc_configuration(self):
+    def get_extended_bmc_configuration(self, hideadvanced=True):
         if self.has_xcc:
-            return self.immhandler.get_extended_bmc_configuration()
+            return self.immhandler.get_extended_bmc_configuration(hideadvanced=hideadvanced)
         return super(OEMHandler, self).get_extended_bmc_configuration()
 
     def get_bmc_configuration(self):
