@@ -583,9 +583,18 @@ class Session(object):
             self.broken = True
             if self.socket:
                 self.socketpool[self.socket] -= 1
+        while self.logonwaiters:
+            waiter = self.logonwaiters.pop()
+            try:
+                waiter({'error': 'Session failed to initialize'})
+            except Exception:
+                pass
 
     def onlogon(self, parameter):
         if 'error' in parameter:
+            while self.logonwaiters:
+                waiter = self.logonwaiters.pop()
+                waiter(parameter)
             self._mark_broken(parameter['error'])
         elif self.onlogpayload:
             self._cmdwait()
