@@ -799,7 +799,7 @@ class TsmHandler(generic.OEMHandler):
         raise exc.UnsupportedFunctionality(
             'Remote media upload not supported on this system')
 
-    def list_media(self, fishclient=None):
+    def list_media(self, fishclient=None, cache=True):
         wc = self.wc
         rsp = wc.grab_json_response('/api/settings/media/general')
         cds = rsp['cd_remote_server_address']
