@@ -119,6 +119,7 @@ def str_to_size(sizestr):
 
 
 class OEMHandler(generic.OEMHandler):
+    usegenericsensors = False
     logouturl = '/api/providers/logout'
     bmcname = 'XCC'
     ADP_URL = '/api/dataset/imm_adapters?params=pci_GetAdapters'
@@ -149,6 +150,31 @@ class OEMHandler(generic.OEMHandler):
         self.fwc = None
         self.fwo = None
 
+    def get_screenshot(self, outfile):
+        self.wc.grab_json_response('/api/providers/rp_screenshot')
+        url = '/download/HostScreenShot.png'
+        fd = webclient.FileDownloader(self.wc, url, outfile)
+        fd.start()
+        fd.join()
+
+    def get_extended_bmc_configuration(self, fishclient, hideadvanced=True):
+        immsettings = self.get_system_configuration(fetchimm=True, hideadvanced=hideadvanced)
+        for setting in list(immsettings):
+            if not setting.startswith('IMM.'):
+                del immsettings[setting]
+        return immsettings
+
+    def get_ikvm_methods(self):
+        return ['url']
+
+    def get_ikvm_launchdata(self):
+        access = self._do_web_request('/redfish/v1/Managers/1/Oem/Lenovo/RemoteControl/Actions/LenovoRemoteControlService.GetRemoteConsoleToken', {})
+        if access.get('Token', None):
+            accessinfo = {
+                'url': '/#/login?{}&context=remote&mode=multi'.format(access['Token'])
+                }
+            return accessinfo
+
     def get_system_configuration(self, hideadvanced=True, fishclient=None,
                                  fetchimm=False):
         if not self.fwc:
@@ -285,8 +311,12 @@ class OEMHandler(generic.OEMHandler):
             raise pygexc.UnsupportedFunctionality(
                 'This is not an enclosure manager')
         wc = self.wc.dupe(timeout=5)
-        rsp = wc.grab_json_response_with_status(
-            '/api/providers/virt_reseat', '{}')
+        try:
+            rsp = wc.grab_json_response_with_status(
+                '/api/providers/virt_reseat', '{}')
+        except socket.timeout:
+            # Can't be certain, but most likely a timeout'
+            return
         if rsp[1] == 500 and rsp[0] == 'Target Unavailable':
             return
         if rsp[1] != 200 or rsp[0].get('return', 1) != 0:
@@ -572,7 +602,7 @@ class OEMHandler(generic.OEMHandler):
         summary['badreadings'] = fallbackdata
         return summary
 
-    def get_description(self):
+    def get_description(self, fishclient):
         description = self._do_web_request('/DeviceDescription.json')
         if description:
             description = description[0]
@@ -630,7 +660,9 @@ class OEMHandler(generic.OEMHandler):
                     skipkeys.add(fwi['key'])
                     if fwi.get('fw_status', 0) == 2:
                         bdata = {}
-                        if 'fw_version_pend' in fwi:
+                        if 'fw_pkg_version' in fwi and fwi['fw_pkg_version']:
+                            bdata['version'] = fwi['fw_pkg_version']
+                        elif 'fw_version_pend' in fwi:
                             bdata['version'] = fwi['fw_version_pend']
                         yield '{0} Pending Update'.format(aname), bdata
         for fwi in fdata.get('items', []):
@@ -667,7 +699,7 @@ class OEMHandler(generic.OEMHandler):
             for diskent in adp.get('aimDisks', ()):
                 yield self._get_disk_firmware_single(diskent)
 
-    def get_firmware_inventory(self, components):
+    def get_firmware_inventory(self, components, fishclient):
         sysinf = self.wc.grab_json_response('/api/dataset/sys_info')
         for item in sysinf.get('items', {}):
             for firm in item.get('firmware', []):
@@ -1119,7 +1151,7 @@ class OEMHandler(generic.OEMHandler):
         res = wc.grab_json_response_with_status(url, body, method=method)
         return res
 
-    def list_media(self, fishclient):
+    def list_media(self, fishclient, cache=True):
         rt = self.wc.grab_json_response('/api/providers/rp_vm_remote_getdisk')
         if 'items' in rt:
             for mt in rt['items']:
@@ -1282,11 +1314,15 @@ class OEMHandler(generic.OEMHandler):
             # the validating phase; add a retry here so we don't exit the loop in this case
             retry = 3
             while not complete and retry > 0:
-                pgress = self._do_web_request(monitorurl, cache=False)
+                try:
+                    pgress = self._do_web_request(monitorurl, cache=False)
+                except socket.timeout:
+                    pgress = None
                 if not pgress:
                     retry -= 1
                     time.sleep(3)
                     continue
+                retry = 3 # reset retry counter
                 for msg in pgress.get('Messages', []):
                     if 'Verify failed' in msg.get('Message', ''):
                         raise Exception(msg['Message'])
@@ -1308,6 +1344,8 @@ class OEMHandler(generic.OEMHandler):
                         time.sleep(3)
                 else:
                     time.sleep(3)
+            if not retry:
+                raise Exception('Falied to monitor update progress due to excessive timeouts')
             if bank == 'backup':
                 return 'complete'
             return 'pending'
@@ -1522,8 +1560,12 @@ class OEMHandler(generic.OEMHandler):
         return 'pending'
 
     def get_diagnostic_data(self, savefile, progress=None, autosuffix=False):
-        self.wc.grab_json_response('/api/providers/ffdc',
-                                   {'Generate_FFDC': 1})
+        rsp = self.wc.grab_json_response('/api/providers/ffdc',
+                                         {'Generate_FFDC': 1})
+        if rsp.get('return', 0) == 4:
+            rsp = self.wc.grab_json_response('/api/providers/ffdc',
+                                             {'Generate_FFDC': 1,
+                                              'thermal_log': 0})
         percent = 0
         while percent != 100:
             time.sleep(3)
@@ -1553,7 +1595,7 @@ class OEMHandler(generic.OEMHandler):
             progress({'phase': 'complete'})
         return savefile
 
-    def get_licenses(self):
+    def get_licenses(self, fishclient):
         licdata = self.wc.grab_json_response('/api/providers/imm_fod')
         for lic in licdata.get('items', [{}])[0].get('keys', []):
             if lic['status'] == 0:
@@ -1564,7 +1606,7 @@ class OEMHandler(generic.OEMHandler):
                     'state': 'Missing required license'
                 }
 
-    def delete_license(self, name):
+    def delete_license(self, name, fishclient):
         licdata = self.wc.grab_json_response('/api/providers/imm_fod')
         for lic in licdata.get('items', [{}])[0].get('keys', []):
             if lic.get('feature', None) == name:
@@ -1577,7 +1619,7 @@ class OEMHandler(generic.OEMHandler):
                 )
                 break
 
-    def save_licenses(self, directory):
+    def save_licenses(self, directory, fishclient):
         licdata = self.wc.grab_json_response('/api/providers/imm_fod')
         for lic in licdata.get('items', [{}])[0].get('keys', []):
             licid = ','.join((str(lic['type']), str(lic['id'])))
@@ -1594,7 +1636,7 @@ class OEMHandler(generic.OEMHandler):
                     self._refresh_token()
                 yield savefile
 
-    def apply_license(self, filename, progress=None, data=None):
+    def apply_license(self, filename, fishclient, progress=None, data=None):
         license_errors = {
             310: "License is for a different model of system",
             311: "License is for a different system serial number",
@@ -1618,7 +1660,7 @@ class OEMHandler(generic.OEMHandler):
             if rsp.get('return', 0) in license_errors:
                 raise pygexc.InvalidParameterValue(
                     license_errors[rsp['return']])
-        return self.get_licenses()
+        return self.get_licenses(fishclient)
 
     def user_delete(self, uid):
         userinfo = self.wc.grab_json_response('/api/dataset/imm_users')
