@@ -97,8 +97,9 @@ class FileDownloader(threading.Thread):
 
 
 def get_upload_form(filename, data, formname, otherfields):
+    ffilename = filename.split('/')[-1]
     if not formname:
-        formname = filename
+        formname = ffilename
     try:
         return uploadforms[filename]
     except KeyError:
@@ -106,16 +107,22 @@ def get_upload_form(filename, data, formname, otherfields):
             data = data.read()
         except AttributeError:
             pass
-        form = (b'--' + BND
+        form = b''
+        for ofield in otherfields:
+            tfield = otherfields[ofield]
+            xtra=''
+            if isinstance(tfield, dict):
+                tfield = json.dumps(tfield)
+                xtra = '\r\nContent-Type: application/json'
+            form += (b'--' + BND
+                     + '\r\nContent-Disposition: form-data; '
+                       'name="{0}"{1}\r\n\r\n{2}\r\n'.format(
+                           ofield, xtra, tfield).encode('utf-8'))
+        form += (b'--' + BND
                 + '\r\nContent-Disposition: form-data; '
                   'name="{0}"; filename="{1}"\r\n'.format(
-                      formname, filename).encode('utf-8'))
+                      formname, ffilename).encode('utf-8'))
         form += b'Content-Type: application/octet-stream\r\n\r\n' + data
-        for ofield in otherfields:
-            form += (b'\r\n--' + BND
-                     + '\r\nContent-Disposition: form-data; '
-                       'name="{0}"\r\n\r\n{1}'.format(
-                           ofield, otherfields[ofield]).encode('utf-8'))
         form += b'\r\n--' + BND + b'--\r\n'
         uploadforms[filename] = form
         return form
@@ -160,9 +167,11 @@ class SecureHTTPConnection(httplib.HTTPConnection, object):
             self.sock.close()
             self.sock = None
 
-    def dupe(self):
+    def dupe(self, timeout=None):
+        if timeout is None:
+            timeout = self.mytimeout
         return SecureHTTPConnection(self.thehost, self.theport, clone=self,
-                                    timeout=self.mytimeout)
+                                    timeout=timeout)
 
     def set_header(self, key, value):
         self.stdheaders[key] = value
@@ -270,6 +279,22 @@ class SecureHTTPConnection(httplib.HTTPConnection, object):
             return json.loads(body) if body else {}, rsp.status
         return body, rsp.status
 
+    def grab_rsp(self, url, data=None, referer=None, headers=None, method=None):
+        webclient = self.dupe()
+        if isinstance(data, dict):
+            data = json.dumps(data)
+        if data:
+            if not method:
+                method = 'POST'
+            webclient.request(method, url, data, referer=referer,
+                              headers=headers)
+        else:
+            if not method:
+                method = 'GET'
+            webclient.request(method, url, referer=referer, headers=headers)
+        rsp = webclient.getresponse()
+        return rsp
+
     def download(self, url, file):
         """Download a file to filename or file object
 
@@ -317,11 +342,19 @@ class SecureHTTPConnection(httplib.HTTPConnection, object):
             ulhdrs['Content-Length'] = len(uploadforms[filename])
             self.ulsize = len(uploadforms[filename])
         else:
-            curroff = data.tell()
-            data.seek(0, 2)
-            self.ulsize = data.tell()
-            data.seek(curroff, 0)
-            self._upbuffer = data
+            canseek = True
+            try:
+                curroff = data.tell()
+            except io.UnsupportedOperation:
+                canseek = False
+                databytes = data.read()
+                self.ulsize = len(databytes)
+                self._upbuffer = io.BytesIO(databytes)
+            if canseek:
+                data.seek(0, 2)
+                self.ulsize = data.tell()
+                data.seek(curroff, 0)
+                self._upbuffer = data
             ulhdrs['Content-Type'] = b'application/octet-stream'
             ulhdrs['Content-Length'] = self.ulsize
         webclient = self.dupe()
@@ -380,3 +413,4 @@ class SecureHTTPConnection(httplib.HTTPConnection, object):
         except httplib.CannotSendRequest:
             self.broken = True
             raise
+
